<?php
$TRANSLATIONS = array(
"No file provided for import" => "未提供导入文件",
"Unsupported file type for import" => "不支持导入的文件类型",
"Bookmarks" => "书签",
"Tags" => "标签",
"Filter by tag" => "按标签过滤",
"Edit bookmark" => "编辑书签",
"Are you sure you want to remove this tag from every entry?" => "确定要从所有条目中移除此标签？",
"Warning" => "警告",
"Import error" => "导入错误",
"Import completed successfully." => "导入成功完成。",
"Uploading..." => "上传中……",
"Bookm." => "书签",
"Add a bookmark" => "新增一个书签",
"Close" => "关闭",
"The title of the page" => "页面名称",
"The address of the page" => "页面地址",
"Description of the page" => "页面描述",
"Save" => "保存",
"Delete" => "删除",
"Edit" => "编辑",
"Cancel" => "取消",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "拖曳此处到您的浏览器书签处，点击可以将网页快速增加到书签中。",
"Add to ownCloud" => "增加到 ownCloud",
"Address" => "地址",
"Add" => "增加",
"Related Tags" => "相关标签",
"Settings" => "设置",
"You have no bookmarks" => "您暂无书签",
"You can also try to import a bookmark file" => "您也可以尝试导入一个书签文件",
"Bookmarklet" => "书签",
"Export & Import" => "导入导出",
"Export" => "导出",
"Import" => "导入"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
